from __future__ import annotations

from pathlib import Path

import pooch

__all__ = ["get", "Blob"]


def get(hexhash: str) -> Blob:
    if len(hexhash) != 64:
        raise ValueError("hexhash must be 64 characters long")

    url = f"https://pub.danilohorta.me/{hexhash}"
    path = Path(pooch.retrieve(url=url, known_hash=f"sha256:{hexhash}"))
    return Blob(path, hexhash)


class Blob:
    def __init__(self, path: Path, hexhash: str):
        self._path = path.resolve()
        self._hexhash = hexhash

    def as_path(self, name) -> Path:
        path = self._path.parent / name
        if not path.exists():
            path.hardlink_to(self._path)
        return path

    def __str__(self) -> str:
        return self._hexhash



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['anyblob']

package_data = \
{'': ['*']}

install_requires = \
['pooch>=1.6.0,<2.0.0']

setup_kwargs = {
    'name': 'anyblob',
    'version': '1.0.0',
    'description': '',
    'long_description': '# anyblob\n\nSummon binary objects into your local file system by their SHA-256 hashes.\n',
    'author': 'Danilo Horta',
    'author_email': 'danilo.horta@pm.me',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
